@@ -1,22 +1,3 @@
-/*
- * chamkho - a word breaker written in Rust
- * Copyright (C) 2015  Vee Satayamas
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
-
 pub extern crate wordcut_engine;
 
 use self::wordcut_engine::Dict;
@@ -38,6 +19,14 @@ pub fn lao_path() -> &'static Path {
     Path::new(concat!(env!("CARGO_MANIFEST_DIR"), "/data/laowords.txt"))
 }
 
+pub fn khmer_dict_path() -> &'static Path {
+    Path::new(concat!(env!("CARGO_MANIFEST_DIR"), "/data/khmerdict.txt"))
+}
+
+pub fn myanmar_dict_path() -> &'static Path {
+    Path::new(concat!(env!("CARGO_MANIFEST_DIR"), "/data/myanmar-dict.txt"))
+}
+
 pub fn thai_cluster_path() -> Option<String> {
     Some(concat!(env!("CARGO_MANIFEST_DIR"), "/data/thai_cluster_rules.txt").to_owned())
 }
@@ -46,6 +35,14 @@ pub fn lao_clusters_path() -> Option<String> {
     None
 }
 
+pub fn khmer_clusters_path() -> Option<String> {
+    None
+}
+
+pub fn myanmar_clusters_path() -> Option<String> {
+    None
+}
+
 pub fn load_dict(path: &Path) -> Result<Dict> {
     self::wordcut_engine::load_dict(path)
 }
